@@ -59,6 +59,7 @@ import org.jetbrains.annotations.NotNull;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
@@ -91,6 +92,7 @@ public class DefaultOptimizingService extends StatedPersistentBase
 
   private final long optimizerTouchTimeout;
   private final long taskAckTimeout;
+  private final long taskExecuteTimeout;
   private final int maxPlanningParallelism;
   private final long pollingTimeout;
   private final long refreshGroupInterval;
@@ -114,6 +116,8 @@ public class DefaultOptimizingService extends StatedPersistentBase
         serviceConfig.get(AmoroManagementConf.OPTIMIZER_HB_TIMEOUT).toMillis();
     this.taskAckTimeout =
         serviceConfig.get(AmoroManagementConf.OPTIMIZER_TASK_ACK_TIMEOUT).toMillis();
+    this.taskExecuteTimeout =
+        serviceConfig.get(AmoroManagementConf.OPTIMIZER_TASK_EXECUTE_TIMEOUT).toMillis();
     this.refreshGroupInterval =
         serviceConfig.get(AmoroManagementConf.OPTIMIZING_REFRESH_GROUP_INTERVAL).toMillis();
     this.maxPlanningParallelism =
@@ -239,10 +243,11 @@ public class DefaultOptimizingService extends StatedPersistentBase
   @Override
   public void completeTask(String authToken, OptimizingTaskResult taskResult) {
     LOG.info(
-        "Optimizer {} (threadId {}) complete task {}",
+        "Optimizer {} (threadId {}) complete task {} (status: {})",
         authToken,
         taskResult.getThreadId(),
-        taskResult.getTaskId());
+        taskResult.getTaskId(),
+        taskResult.getErrorMessage() == null ? "SUCCESS" : "FAIL");
     OptimizingQueue queue = getQueueByToken(authToken);
     OptimizerThread thread =
         getAuthenticatedOptimizer(authToken).getThread(taskResult.getThreadId());
@@ -508,10 +513,20 @@ public class DefaultOptimizingService extends StatedPersistentBase
     }
 
     private void retryTask(TaskRuntime<?> task, OptimizingQueue queue) {
-      LOG.info(
-          "Task {} is suspending, since it's optimizer is expired, put it to retry queue, optimizer {}",
-          task.getTaskId(),
-          task.getResourceDesc());
+      if (task.getStatus() == TaskRuntime.Status.ACKED
+          && task.getStartTime() + taskExecuteTimeout < System.currentTimeMillis()) {
+        LOG.warn(
+            "Task {} has been suspended in ACK state for {} (start time: {}), put it to retry queue, optimizer {}. (Note: The task may have finished executing, but ams did not receive the COMPLETE message from the optimizer.)",
+            task.getTaskId(),
+            Duration.ofMillis(taskExecuteTimeout),
+            task.getStartTime(),
+            task.getResourceDesc());
+      } else {
+        LOG.info(
+            "Task {} is suspending, since it's optimizer is expired, put it to retry queue, optimizer {}",
+            task.getTaskId(),
+            task.getResourceDesc());
+      }
       // optimizing task of suspending optimizer would not be counted for retrying
       try {
         queue.retryTask(task);
@@ -529,7 +544,9 @@ public class DefaultOptimizingService extends StatedPersistentBase
                   && !activeTokens.contains(task.getToken())
                   && task.getStatus() != TaskRuntime.Status.SUCCESS
               || task.getStatus() == TaskRuntime.Status.SCHEDULED
-                  && task.getStartTime() + taskAckTimeout < System.currentTimeMillis();
+                  && task.getStartTime() + taskAckTimeout < System.currentTimeMillis()
+              || task.getStatus() == TaskRuntime.Status.ACKED
+                  && task.getStartTime() + taskExecuteTimeout < System.currentTimeMillis();
     }
   }
 
