@@ -72,6 +72,7 @@ import org.slf4j.LoggerFactory;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.ByteBuffer;
 import java.time.Instant;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
@@ -321,13 +322,19 @@ public class IcebergTableMaintainer implements TableMaintainer {
     // so acquire in advance
     // to prevent repeated acquisition
     Set<String> validFiles = orphanFileCleanNeedToExcludeFiles();
-    LOG.info("Starting cleaning orphan content files for table {}", table.name());
+    LOG.info(
+        "Starting cleaning orphan content files for table {} before {}",
+        table.name(),
+        Instant.ofEpochMilli(lastTime));
     clearInternalTableContentsFiles(lastTime, validFiles, orphanFilesCleaningMetrics);
   }
 
   protected void cleanMetadata(
       long lastTime, TableOrphanFilesCleaningMetrics orphanFilesCleaningMetrics) {
-    LOG.info("Starting cleaning metadata files for table {}", table.name());
+    LOG.info(
+        "Starting cleaning metadata files for table {} before {}",
+        table.name(),
+        Instant.ofEpochMilli(lastTime));
     clearInternalTableMetadata(lastTime, orphanFilesCleaningMetrics);
   }
 
@@ -968,28 +975,29 @@ public class IcebergTableMaintainer implements TableMaintainer {
       String numberDateFormatter,
       Comparable<?> expireValue) {
     Type type = field.type();
-    Object upperBound =
-        Conversions.fromByteBuffer(type, contentFile.upperBounds().get(field.fieldId()));
     Literal<Long> literal = Literal.of(Long.MAX_VALUE);
-    if (null == upperBound) {
-      if (canBeExpireByPartitionValue(contentFile, field, expireValue)) {
-        literal = Literal.of(0L);
+
+    Map<Integer, ByteBuffer> upperBounds = contentFile.upperBounds();
+    if (upperBounds == null || !upperBounds.containsKey(field.fieldId())) {
+      return canBeExpireByPartitionValue(contentFile, field, expireValue)
+          ? Literal.of(0L)
+          : literal;
+    }
+
+    Object upperBound = Conversions.fromByteBuffer(type, upperBounds.get(field.fieldId()));
+    if (upperBound instanceof Long) {
+      if (type.typeId() == Type.TypeID.TIMESTAMP) {
+        // nanosecond -> millisecond
+        literal = Literal.of((Long) upperBound / 1000);
+      } else {
+        if (numberDateFormatter.equals(EXPIRE_TIMESTAMP_MS)) {
+          literal = Literal.of((Long) upperBound);
+        } else if (numberDateFormatter.equals(EXPIRE_TIMESTAMP_S)) {
+          // second -> millisecond
+          literal = Literal.of((Long) upperBound * 1000);
+        }
       }
-    } else if (upperBound instanceof Long) {
-      switch (type.typeId()) {
-        case TIMESTAMP:
-          // nanosecond -> millisecond
-          literal = Literal.of((Long) upperBound / 1000);
-          break;
-        default:
-          if (numberDateFormatter.equals(EXPIRE_TIMESTAMP_MS)) {
-            literal = Literal.of((Long) upperBound);
-          } else if (numberDateFormatter.equals(EXPIRE_TIMESTAMP_S)) {
-            // second -> millisecond
-            literal = Literal.of((Long) upperBound * 1000);
-          }
-      }
-    } else if (type.typeId().equals(Type.TypeID.STRING)) {
+    } else if (type.typeId() == Type.TypeID.STRING) {
       literal =
           Literal.of(
               LocalDate.parse(upperBound.toString(), formatter)
@@ -1020,6 +1028,11 @@ public class IcebergTableMaintainer implements TableMaintainer {
                 .apply(expireValue);
         Comparable<Object> filePartitionValue =
             contentFile.partition().get(pos, partitionUpperBound.getClass());
+        // if the partition value is null, can not determine if it can be expired
+        if (filePartitionValue == null) {
+          return false;
+        }
+
         int compared = filePartitionValue.compareTo(partitionUpperBound);
         Boolean compareResult =
             expireField.type() == Types.StringType.get() ? compared <= 0 : compared < 0;
