@@ -48,7 +48,6 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.util.ArrayList;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
@@ -198,6 +197,12 @@ public class DefaultTableService extends PersistentBase implements TableService
     return tableRuntimeMap.get(tableId);
   }
 
+  @VisibleForTesting
+  public void setRuntime(TableRuntime tableRuntime) {
+    checkStarted();
+    tableRuntimeMap.put(tableRuntime.getTableIdentifier().getId(), tableRuntime);
+  }
+
   @Override
   public boolean contains(Long tableId) {
     checkStarted();
@@ -275,18 +280,17 @@ public class DefaultTableService extends PersistentBase implements TableService
               try {
                 tableIdentifiersFutures.add(
                     CompletableFuture.supplyAsync(
-                        () -> {
-                          try {
-                            return externalCatalog.listTables(database).stream()
-                                .map(TableIdentity::new)
-                                .collect(Collectors.toSet());
-                          } catch (Exception e) {
-                            LOG.error(
-                                "TableExplorer list tables in database {} error", database, e);
-                            return new HashSet<>();
-                          }
-                        },
-                        tableExplorerExecutors));
+                            () ->
+                                externalCatalog.listTables(database).stream()
+                                    .map(TableIdentity::new)
+                                    .collect(Collectors.toSet()),
+                            tableExplorerExecutors)
+                        .exceptionally(
+                            ex -> {
+                              LOG.error(
+                                  "TableExplorer list tables in database {} error", database, ex);
+                              throw new RuntimeException(ex);
+                            }));
               } catch (RejectedExecutionException e) {
                 LOG.error(
                     "The queue of table explorer is full, please increase the queue size or thread count.");
@@ -467,7 +471,8 @@ public class DefaultTableService extends PersistentBase implements TableService
     }
   }
 
-  private void disposeTable(ServerTableIdentifier tableIdentifier) {
+  @VisibleForTesting
+  public void disposeTable(ServerTableIdentifier tableIdentifier) {
     TableRuntime existedTableRuntime = tableRuntimeMap.get(tableIdentifier.getId());
     try {
       doAsTransaction(
@@ -484,6 +489,7 @@ public class DefaultTableService extends PersistentBase implements TableService
                               tableIdentifier.getId()); // remove only after successful operation
                         } catch (Exception e) {
                           LOG.error("Error occurred while disposing table {}", tableIdentifier, e);
+                          throw e;
                         }
                       }),
           () ->
